@@ -1,13 +1,13 @@
 #' Zhong's 2-/3- stage Phase II design
 #' @description calculate optimal 2-/3-stage design given by Bob Zhong
-#' @details The two-stage design setup is: n1 patients are treated in the first stage. At the end of the first stage, either the trial continues to the second stage or inefficacy is concluded and the trial is stopped (early termination), depending on the number of responses observed at the first stage. If the trial does continue to the second stage, additional n2 patients are treated. Three-stage design is an extension of two-stage design where one stage is added between Stage 1 and 2. The left-side rejection region is response <= r_i for i = 1, 2, or 3 and right-side rejection region is  response > s. Alpha-spending method is added to two-/three-stage designs. \code{opt.design} supports Hwang-Shih-DeCani spending function. You may change the definition of \code{my_sfHSD} function to use a different spending function. 
+#' @details The two-stage design setup is: n1 patients are treated in the first stage. At the end of the first stage, either the trial continues to the second stage or inefficacy is concluded and the trial is stopped (early termination), depending on the number of responses observed at the first stage. If the trial does continue to the second stage, additional n2 patients are treated. Three-stage design is an extension of two-stage design where one stage is added between Stage 1 and 2. The left-side rejection region is response <= r_i for i = 1, 2, or 3 and right-side rejection region is  response > s. Alpha-spending method is added to two-/three-stage designs. \code{opt.design} supports Hwang-Shih-DeCani spending function. You can change the definition of \code{HSD} function to use a different spending function. 
 #' @param alpha1 left-side overall type I error. 
 #' @param alpha2 right-side overall type I error.
 #' @param beta type II error
 #' @param pc a numeric vector of response rate. should be a vector with length 1 or 2.
-#' @param pt alternative hypothesis
+#' @param pe alternative hypothesis.
 #' @param stage 2 or 3. default to 2 (2-stage design).
-#' @param two.sided logical flag. default to \code{FALSE}. if \code{two.sided = TRUE}, the trial may stop for superiority before the last stage.
+#' @param stop.eff logical flag. default to \code{FALSE}. if \code{stop.eff = TRUE}, the trial may stop for efficacy at interim.
 #' @param frac_n1 proportion of n1. for 2-stage design, default to \code{c(0.3, 0.6)}, i.e. the range of \code{n1} is \code{0.2*n} to \code{0.5*n}. for 3-stage design, default to \code{c(0.2, 0.3)}, i.e. the range of \code{n1} is \code{0.2*n} to \code{0.3*n}
 #' @param frac_n2 proportion of n2. Used for 3-stage design. default to \code{c(0.2, 0.4)}.
 #' @param sf.param  a single real value specifying the gamma parameter for which Hwang-Shih-DeCani spending is to be computed; allowable range is [-40, 40]. Increasing this parameter implies that more error is spent early stage and less is available in late stage. For two-stage designs, default to \code{NULL}(alpha-spending is not used); for three-stage designs, default to 4.
@@ -24,10 +24,10 @@
 #'  \item{alpha2}{input; right-side type 1 error}
 #'  \item{beta}{input; type 2 error}
 #'  \item{pc}{input; a vector of response rate.}
-#'  \item{pt}{input; a vector of alternative response rate}
+#'  \item{pe}{input; a vector of alternative response rate}
 #'  \item{sf}{input; the alpha-spending function used}
 #'  \item{stage}{input; two- or three- stage design is used}
-#' @author Wenchuan Guo <wguo1017@gmail.com>
+#' @author Wenchuan Guo <wguo1017@gmail.com>, Jianan Hui <jiananhuistat@gmail.com>
 #' @references
 #' Zhong. (2012) Single-arm Phase IIA clinical trials with go/no-go decisions. \emph{Contemporary Clinical Trials}, \bold{33}, 1272--1279.
 #' @import stats
@@ -37,9 +37,9 @@
 #'  alpha2 <- 0.10
 #'  beta <- 0.15
 #'  pc <- 0.25
-#'  pt <- pc + 0.20
+#'  pe <- pc + 0.20
 #'  # calculate optimal two-stage design without using alpha-spending
-#'  opt.design(alpha1, alpha2, beta, pc, pt, stage=2)
+#'  opt.design(alpha1, alpha2, beta, pc, pe, stage=2)
 #'  \dontrun{
 #'  # calculate optimal two-stage design with Pocock-like spending function 
 #'  opt.design(alpha1, alpha2, beta, pc, pt, stage = 2, sf.param = 1)
@@ -48,7 +48,7 @@
 #'  opt.design(alpha1, alpha2, beta, pc, pt, stage = 3, sf.param = -4)
 #'  }
 
-opt.design <- function(alpha1, alpha2, beta, pc, pt, stage = 2, two.sided = FALSE, frac_n1 = NULL, frac_n2 = NULL, sf.param = NULL, show = FALSE, nmax = 100, n.choice = 1, ...) {
+opt.design <- function(alpha1, alpha2, beta, pc, pe, stage = 2, stop.eff = FALSE, frac_n1 = NULL, frac_n2 = NULL, sf.param = NULL, show = FALSE, nmax = 100, n.choice = 1, ...) {
   if(stage !=2 & stage !=3){
     stop("only support two and three stage designs")
   }
@@ -63,15 +63,15 @@ opt.design <- function(alpha1, alpha2, beta, pc, pt, stage = 2, two.sided = FALS
   }
   if(stage == 2) {
     if(is.null(frac_n1)) frac_n1 <- c(0.3, 0.6)
-    out <- zhong.two(alpha1, alpha2, beta, pc, pt, two.sided, sf.param, show, nmax, n.choice, frac_n1)
+    out <- zhong.two(alpha1, alpha2, beta, pc, pe, stop.eff, sf.param, show, nmax, n.choice, frac_n1)
   } 
   if(stage == 3) {
     if(is.null(sf.param)) sf.param <- 4
     if(is.null(frac_n1)) frac_n1 <- c(0.2, 0.3)
     if(is.null(frac_n2)) frac_n2 <- c(0.2, 0.4)
-    out <- zhong.three(alpha1, alpha2, beta, pc, pt, frac_n1, frac_n2, sf.param, two.sided, show, nmax)
+    out <- zhong.three(alpha1, alpha2, beta, pc, pe, frac_n1, frac_n2, sf.param, stop.eff, show, nmax)
   }
-  input <- list(alpha1 = alpha1, alpha2 = alpha2, beta = beta, pc = pc, pt = pt, sf.param = sf.param, stage = stage, frac_n1 = frac_n1, frac_n2 = frac_n2)
+  input <- list(alpha1 = alpha1, alpha2 = alpha2, beta = beta, pc = pc, pe = pe, sf.param = sf.param, stage = stage, frac_n1 = frac_n1, frac_n2 = frac_n2)
   out <- c(out, input)
   class(out) <- "opt.design"
   return(out)
